==> webkit2gtk_2.25.1.orig.tar.xz: webkitgtk-2.25.1/Source/WebCore/html/HTMLIFrameElement.h <==
/*
 * Copyright (C) 1999 Lars Knoll (knoll@kde.org)
 *           (C) 1999 Antti Koivisto (koivisto@kde.org)
 *           (C) 2000 Simon Hausmann <hausmann@kde.org>
 * Copyright (C) 2004, 2006, 2008, 2009 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#pragma once

#include "FeaturePolicy.h"
#include "HTMLFrameElementBase.h"

namespace WebCore {

class DOMTokenList;
class RenderIFrame;

class HTMLIFrameElement final : public HTMLFrameElementBase {
    WTF_MAKE_ISO_ALLOCATED(HTMLIFrameElement);
public:
    static Ref<HTMLIFrameElement> create(const QualifiedName&, Document&);

    DOMTokenList& sandbox();

    RenderIFrame* renderer() const;
    const String& allow() const { return m_allow; }

    void setReferrerPolicyForBindings(const AtomicString&);
    String referrerPolicyForBindings() const;
    ReferrerPolicy referrerPolicy() const final;

    const FeaturePolicy& featurePolicy() const;

private:
    HTMLIFrameElement(const QualifiedName&, Document&);

#if PLATFORM(IOS_FAMILY)
    bool isKeyboardFocusable(KeyboardEvent*) const final { return false; }
#endif

    void parseAttribute(const QualifiedName&, const AtomicString&) final;
    bool isPresentationAttribute(const QualifiedName&) const final;
    void collectStyleForPresentationAttribute(const QualifiedName&, const AtomicString&, MutableStyleProperties&) final;

    bool rendererIsNeeded(const RenderStyle&) final;
    RenderPtr<RenderElement> createElementRenderer(RenderStyle&&, const RenderTreePosition&) final;

    std::unique_ptr<DOMTokenList> m_sandbox;
    String m_allow;
    mutable Optional<FeaturePolicy> m_featurePolicy;
};

} // namespace WebCore

==> webkit2gtk_2.25.2.orig.tar.xz: webkitgtk-2.25.2/Source/WebCore/html/HTMLIFrameElement.h <==
/*
 * Copyright (C) 1999 Lars Knoll (knoll@kde.org)
 *           (C) 1999 Antti Koivisto (koivisto@kde.org)
 *           (C) 2000 Simon Hausmann <hausmann@kde.org>
 * Copyright (C) 2004, 2006, 2008, 2009 Apple Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#pragma once

#include "FeaturePolicy.h"
#include "HTMLFrameElementBase.h"

namespace WebCore {

class DOMTokenList;
class RenderIFrame;

class HTMLIFrameElement final : public HTMLFrameElementBase {
    WTF_MAKE_ISO_ALLOCATED(HTMLIFrameElement);
public:
    static Ref<HTMLIFrameElement> create(const QualifiedName&, Document&);

    DOMTokenList& sandbox();

    RenderIFrame* renderer() const;
    const String& allow() const { return m_allow; }

    void setReferrerPolicyForBindings(const AtomString&);
    String referrerPolicyForBindings() const;
    ReferrerPolicy referrerPolicy() const final;

    const FeaturePolicy& featurePolicy() const;

private:
    HTMLIFrameElement(const QualifiedName&, Document&);

#if PLATFORM(IOS_FAMILY)
    bool isKeyboardFocusable(KeyboardEvent*) const final { return false; }
#endif

    void parseAttribute(const QualifiedName&, const AtomString&) final;
    bool isPresentationAttribute(const QualifiedName&) const final;
    void collectStyleForPresentationAttribute(const QualifiedName&, const AtomString&, MutableStyleProperties&) final;

    bool rendererIsNeeded(const RenderStyle&) final;
    RenderPtr<RenderElement> createElementRenderer(RenderStyle&&, const RenderTreePosition&) final;

    std::unique_ptr<DOMTokenList> m_sandbox;
    String m_allow;
    mutable Optional<FeaturePolicy> m_featurePolicy;
};

} // namespace WebCore
